@@ -36,11 +36,11 @@ module GLib
     end
 
     def tail
-      self.class.wrap(element_type, @struct[:next])
+      self.class.wrap(element_type, struct[:next])
     end
 
     def head
-      GirFFI::ArgHelper.cast_from_pointer(element_type, @struct[:data])
+      GirFFI::ArgHelper.cast_from_pointer(element_type, struct[:data])
     end
 
     def reset_typespec(typespec)
@@ -60,6 +60,7 @@ module GLib
 
     def next_element
       return unless @current
+
       element = @current.head
       @current = @current.tail
       element
