@@ -5,14 +5,14 @@ GLib.load_class :Variant
 module GLib
   # Overrides for GVariant, GLib's variant data type.
   class Variant
-    setup_instance_method 'get_string'
+    setup_instance_method! 'get_string'
 
     def get_string_with_override
       get_string_without_override.first
     end
 
-    alias_method :get_string_without_override, :get_string
-    alias_method :get_string, :get_string_with_override
+    alias get_string_without_override get_string
+    alias get_string get_string_with_override
 
     # Initializing method used in constructors. For Variant, this needs to sink
     # the variant's floating reference.
