@@ -18,6 +18,7 @@ require 'gir_ffi/signal_not_found_error'
 module GObject
   def self.type_from_instance_pointer(inst_ptr)
     return nil if inst_ptr.null?
+
     klsptr = inst_ptr.get_pointer 0
     klsptr.get_gtype 0
   end
@@ -36,6 +37,7 @@ module GObject
 
   def self.object_class_from_instance_pointer(inst_ptr)
     return nil if inst_ptr.null?
+
     klsptr = inst_ptr.get_pointer 0
     ObjectClass.wrap klsptr
   end
@@ -62,6 +64,7 @@ module GObject
 
   def self.signal_connect(object, detailed_signal, data = nil, after = false, &block)
     raise ArgumentError, 'Block needed' unless block_given?
+
     signal_name, = detailed_signal.split('::')
     sig_info = object.class.find_signal signal_name
 
@@ -92,11 +95,6 @@ module GObject
     attach_function :g_value_init, [:pointer, :size_t], :pointer
     attach_function :g_value_unset, [:pointer], :pointer
 
-    attach_function :g_array_get_type, [], :size_t
-    attach_function :g_byte_array_get_type, [], :size_t
-    attach_function :g_hash_table_get_type, [], :size_t
-    attach_function :g_strv_get_type, [], :size_t
-
     attach_function :g_signal_connect_data,
                     [:pointer, :string, Callback, :pointer, ClosureNotify, ConnectFlags],
                     :ulong
@@ -111,9 +109,4 @@ module GObject
 
     attach_function :g_type_class_ref, [:size_t], :pointer
   end
-
-  TYPE_ARRAY = Lib.g_array_get_type
-  TYPE_BYTE_ARRAY = Lib.g_byte_array_get_type
-  TYPE_HASH_TABLE = Lib.g_hash_table_get_type
-  TYPE_STRV = Lib.g_strv_get_type
 end
