@@ -7,24 +7,46 @@ GObject.load_class :Object
 module GObject
   # Overrides for GObject, GObject's generic base class.
   class Object
-    setup_method 'new'
     if !GLib.check_version(2, 54, 0)
-      setup_method 'newv'
+      GObject::Lib.attach_function(:g_object_new_with_properties,
+                                   [:size_t, :uint32, :pointer, :pointer],
+                                   :pointer)
 
-      def initialize_with_automatic_gtype(properties = {})
-        names = []
-        values = []
-        properties.each do |name, value|
-          name = name.to_s
-          gvalue = gvalue_for_property(name)
-          gvalue.set_value value
+      def self.new_with_properties(*args, &block)
+        obj = allocate
+        obj.__send__ :initialize_with_properties, *args, &block
+        obj
+      end
 
-          names << name
-          values << gvalue
-        end
-        initialize_without_automatic_gtype(self.class.gtype, names, values)
+      # Starting with GLib 2.54.0, use g_object_new_with_properties, which
+      # takes an array of names and an array of values.
+      def initialize_with_properties(properties = {})
+        names, gvalues = names_and_gvalues_for_properties(properties)
+
+        n_properties = names.length
+        names_arr = GirFFI::SizedArray.from(:utf8, -1, names)
+        gvalues_arr = GirFFI::SizedArray.from(GObject::Value, -1, gvalues)
+
+        ptr = GObject::Lib.g_object_new_with_properties(self.class.gtype,
+                                                        n_properties,
+                                                        names_arr,
+                                                        gvalues_arr)
+        store_pointer ptr
+      end
+
+      alias old_initialze initialize
+      alias initialize initialize_with_properties
+      remove_method :old_initialze
+
+      def self.new(*args, &block)
+        obj = allocate
+        obj.__send__ :initialize, *args, &block
+        obj
       end
     else
+      setup_method! 'new'
+
+      # Before GLib 2.54.0, use g_object_newv, which takes an array of GParameter.
       def initialize_with_automatic_gtype(properties = {})
         gparameters = properties.map do |name, value|
           name = name.to_s
@@ -36,11 +58,12 @@ module GObject
         end
         initialize_without_automatic_gtype(self.class.gtype, gparameters)
       end
+
+      alias initialize_without_automatic_gtype initialize
+      alias initialize initialize_with_automatic_gtype
     end
 
-    alias_method :initialize_without_automatic_gtype, :initialize
-    alias_method :initialize, :initialize_with_automatic_gtype
-    alias_method :base_initialize, :initialize
+    alias base_initialize initialize
 
     private :base_initialize
 
@@ -59,7 +82,7 @@ module GObject
     def self.make_finalizer(ptr)
       proc do
         rc = GObject::Object::Struct.new(ptr)[:ref_count]
-        if rc.zero?
+        if rc == 0
           warn "not unreffing #{name}:#{ptr} (#{rc})"
         else
           GObject::Lib.g_object_unref ptr
@@ -71,6 +94,7 @@ module GObject
     def method_missing(method, *args)
       getter_name = "get_#{method}"
       return send(getter_name, *args) if respond_to?(getter_name)
+
       if method.to_s =~ /(.*)=$/
         setter_name = "set_#{Regexp.last_match[1]}"
         return send(setter_name, *args) if respond_to?(setter_name)
@@ -90,8 +114,8 @@ module GObject
       GObject.signal_connect_after(self, event, data, &block)
     end
 
-    setup_instance_method 'get_property'
-    setup_instance_method 'set_property'
+    setup_instance_method! 'get_property'
+    setup_instance_method! 'set_property'
 
     def get_property_extended(property_name)
       value = get_property(property_name)
@@ -117,17 +141,29 @@ module GObject
       set_property_without_override property_name, gvalue
     end
 
-    alias_method :get_property_without_override, :get_property
-    alias_method :get_property, :get_property_with_override
+    alias get_property_without_override get_property
+    alias get_property get_property_with_override
 
-    alias_method :set_property_without_override, :set_property
-    alias_method :set_property, :set_property_with_override
+    alias set_property_without_override set_property
+    alias set_property set_property_with_override
 
-    setup_instance_method 'is_floating'
-    alias_method :floating?, :is_floating
+    setup_instance_method! 'is_floating'
+    alias floating? is_floating
 
     private
 
+    def names_and_gvalues_for_properties(properties)
+      return [], [] unless properties.any?
+
+      properties.map do |name, value|
+        name = name.to_s
+        gvalue = gvalue_for_property(name)
+        gvalue.set_value value
+
+        [name, gvalue]
+      end.transpose
+    end
+
     def get_property_type(property_name)
       prop = self.class.find_property(property_name)
       prop.property_type
