@@ -58,10 +58,10 @@ module GObject
       send set_method, val
     end
 
-    alias_method :value=, :set_value
+    alias value= set_value
 
     def current_gtype
-      @struct[:g_type]
+      struct[:g_type]
     end
 
     def current_fundamental_type
@@ -140,13 +140,14 @@ module GObject
 
     def init_for_ruby_value(val)
       return init val.class.gtype if val.class.respond_to? :gtype
+
       CLASS_TO_GTYPE_MAP.each do |klass, type|
         return init type if val.is_a? klass
       end
       raise "Can't handle #{val.class}"
     end
 
-    def set_none(_); end
+    def set_none(_val); end
 
     def get_none; end
 
@@ -169,9 +170,9 @@ module GObject
     end
 
     def check_type_compatibility(val)
-      unless GObject::Value.type_compatible(GObject.type_from_instance(val), current_gtype)
-        raise ArgumentError, "#{val.class} is incompatible with #{current_gtype_name}"
-      end
+      return if GObject::Value.type_compatible(GObject.type_from_instance(val), current_gtype)
+
+      raise ArgumentError, "#{val.class} is incompatible with #{current_gtype_name}"
     end
 
     def wrap_boxed(boxed)
