@@ -5,21 +5,21 @@ module GObjectIntrospection
   # If it represents a flag, an IFlagsInfo object is used instead.
   class IEnumInfo < IRegisteredTypeInfo
     def n_values
-      Lib.g_enum_info_get_n_values @gobj
+      Lib.g_enum_info_get_n_values self
     end
 
     def value(index)
-      IValueInfo.wrap Lib.g_enum_info_get_value(@gobj, index)
+      IValueInfo.wrap Lib.g_enum_info_get_value(self, index)
     end
     ##
     build_array_method :values
 
     def get_n_methods
-      Lib.g_enum_info_get_n_methods @gobj
+      Lib.g_enum_info_get_n_methods self
     end
 
     def get_method(index)
-      IFunctionInfo.wrap Lib.g_enum_info_get_method(@gobj, index)
+      IFunctionInfo.wrap Lib.g_enum_info_get_method(self, index)
     end
 
     ##
@@ -27,7 +27,7 @@ module GObjectIntrospection
     build_finder_method :find_method, :get_n_methods, :get_method
 
     def storage_type
-      Lib.g_enum_info_get_storage_type @gobj
+      Lib.g_enum_info_get_storage_type self
     end
   end
 end
