@@ -5,11 +5,11 @@ module GObjectIntrospection
   # Represents a function or method.
   class IFunctionInfo < ICallableInfo
     def symbol
-      Lib.g_function_info_get_symbol @gobj
+      Lib.g_function_info_get_symbol self
     end
 
     def flags
-      Lib.g_function_info_get_flags @gobj
+      Lib.g_function_info_get_flags self
     end
 
     def method?
