@@ -12,7 +12,11 @@ module GObjectIntrospection
   # This class wraps the GIRepository struct.
   class IRepository
     def initialize
-      @gobj = Lib.g_irepository_get_default
+      @pointer = Lib.g_irepository_get_default
+    end
+
+    def to_ptr
+      @pointer
     end
 
     include Singleton
@@ -32,18 +36,18 @@ module GObjectIntrospection
     def require(namespace, version = nil, flags = 0)
       errpp = FFI::MemoryPointer.new(:pointer).write_pointer nil
 
-      Lib.g_irepository_require @gobj, namespace, version, flags, errpp
+      Lib.g_irepository_require self, namespace, version, flags, errpp
 
       errp = errpp.read_pointer
       raise GError.new(errp).message unless errp.null?
     end
 
     def n_infos(namespace)
-      Lib.g_irepository_get_n_infos @gobj, namespace
+      Lib.g_irepository_get_n_infos self, namespace
     end
 
     def info(namespace, index)
-      wrap_info Lib.g_irepository_get_info(@gobj, namespace, index)
+      wrap_info Lib.g_irepository_get_info(self, namespace, index)
     end
 
     # Utility method
@@ -54,30 +58,32 @@ module GObjectIntrospection
     end
 
     def find_by_name(namespace, name)
-      wrap_info Lib.g_irepository_find_by_name(@gobj, namespace, name)
+      wrap_info Lib.g_irepository_find_by_name(self, namespace, name)
     end
 
     def find_by_gtype(gtype)
-      raise ArgumentError, "Type #{gtype} is not a valid type" if gtype.zero?
-      wrap_info Lib.g_irepository_find_by_gtype(@gobj, gtype)
+      raise ArgumentError, "Type #{gtype} is not a valid type" if gtype == 0
+
+      wrap_info Lib.g_irepository_find_by_gtype(self, gtype)
     end
 
     def dependencies(namespace)
-      strv_p = Lib.g_irepository_get_dependencies(@gobj, namespace)
+      strv_p = Lib.g_irepository_get_dependencies(self, namespace)
       strv = Strv.new strv_p
       strv.to_a
     end
 
     def shared_library(namespace)
-      Lib.g_irepository_get_shared_library @gobj, namespace
+      Lib.g_irepository_get_shared_library self, namespace
     end
 
     def version(namespace)
-      Lib.g_irepository_get_version @gobj, namespace
+      Lib.g_irepository_get_version self, namespace
     end
 
     def self.wrap_ibaseinfo_pointer(ptr)
       return nil if ptr.null?
+
       type = Lib.g_base_info_get_type ptr
       klass = TYPEMAP[type]
       klass.wrap ptr
