@@ -5,11 +5,11 @@ module GObjectIntrospection
   # Represents a struct.
   class IStructInfo < IRegisteredTypeInfo
     def n_fields
-      Lib.g_struct_info_get_n_fields @gobj
+      Lib.g_struct_info_get_n_fields self
     end
 
     def field(index)
-      IFieldInfo.wrap Lib.g_struct_info_get_field(@gobj, index)
+      IFieldInfo.wrap Lib.g_struct_info_get_field(self, index)
     end
 
     ##
@@ -17,11 +17,11 @@ module GObjectIntrospection
     build_finder_method :find_field
 
     def get_n_methods
-      Lib.g_struct_info_get_n_methods @gobj
+      Lib.g_struct_info_get_n_methods self
     end
 
     def get_method(index)
-      IFunctionInfo.wrap Lib.g_struct_info_get_method(@gobj, index)
+      IFunctionInfo.wrap Lib.g_struct_info_get_method(self, index)
     end
 
     ##
@@ -30,15 +30,19 @@ module GObjectIntrospection
     build_finder_method :find_method, :get_n_methods, :get_method
 
     def size
-      Lib.g_struct_info_get_size @gobj
+      Lib.g_struct_info_get_size self
+    end
+
+    def empty?
+      size == 0
     end
 
     def alignment
-      Lib.g_struct_info_get_alignment @gobj
+      Lib.g_struct_info_get_alignment self
     end
 
     def gtype_struct?
-      Lib.g_struct_info_is_gtype_struct @gobj
+      Lib.g_struct_info_is_gtype_struct self
     end
   end
 end
