@@ -5,36 +5,36 @@ module GObjectIntrospection
   # Represents type information, direction, transfer etc.
   class ITypeInfo < IBaseInfo
     def pointer?
-      Lib.g_type_info_is_pointer @gobj
+      Lib.g_type_info_is_pointer self
     end
 
     def tag
-      Lib.g_type_info_get_tag @gobj
+      Lib.g_type_info_get_tag self
     end
 
     def param_type(index)
-      ITypeInfo.wrap Lib.g_type_info_get_param_type(@gobj, index)
+      ITypeInfo.wrap Lib.g_type_info_get_param_type(self, index)
     end
 
     def interface
-      ptr = Lib.g_type_info_get_interface @gobj
+      ptr = Lib.g_type_info_get_interface self
       IRepository.wrap_ibaseinfo_pointer ptr
     end
 
     def array_length
-      Lib.g_type_info_get_array_length @gobj
+      Lib.g_type_info_get_array_length self
     end
 
     def array_fixed_size
-      Lib.g_type_info_get_array_fixed_size @gobj
+      Lib.g_type_info_get_array_fixed_size self
     end
 
     def array_type
-      Lib.g_type_info_get_array_type @gobj
+      Lib.g_type_info_get_array_type self
     end
 
     def zero_terminated?
-      Lib.g_type_info_is_zero_terminated @gobj
+      Lib.g_type_info_is_zero_terminated self
     end
 
     def name
