@@ -40,4 +40,9 @@ module GObject
   TYPE_OBJECT = type_from_name('GObject')
   TYPE_GTYPE = type_from_name('GType')
   TYPE_VARIANT = type_from_name('GVariant')
+
+  TYPE_ARRAY = Lib.g_array_get_type
+  TYPE_BYTE_ARRAY = Lib.g_byte_array_get_type
+  TYPE_HASH_TABLE = Lib.g_hash_table_get_type
+  TYPE_STRV = Lib.g_strv_get_type
 end
