@@ -32,9 +32,7 @@ module GirFFI
       end
 
       def return_value_name
-        if has_output_value?
-          post_converted_name unless array_length_parameter?
-        end
+        post_converted_name if has_output_value? && !array_length_parameter?
       end
 
       def capture_variable_name
@@ -42,23 +40,16 @@ module GirFFI
       end
 
       def pre_conversion
-        pr = []
-        if has_ingoing_component?
-          pr << fixed_array_size_check if needs_size_check?
-          pr << array_length_assignment if array_length_parameter?
-        end
         case direction
         when :in
-          pr << "#{call_argument_name} = #{ingoing_convertor.conversion}"
+          pre_conversion_in
         when :inout
-          pr << out_parameter_preparation
-          pr << ingoing_value_storage
+          pre_conversion_inout
         when :out
-          pr << out_parameter_preparation
+          pre_conversion_out
         when :error
-          pr << "#{call_argument_name} = FFI::MemoryPointer.new(:pointer).write_pointer nil"
+          pre_conversion_error
         end
-        pr
       end
 
       def post_conversion
@@ -74,6 +65,31 @@ module GirFFI
 
       private
 
+      def pre_conversion_in
+        pr = []
+        pr << fixed_array_size_check if needs_size_check?
+        pr << array_length_assignment if array_length_parameter?
+        pr << "#{call_argument_name} = #{ingoing_convertor.conversion}"
+        pr
+      end
+
+      def pre_conversion_inout
+        pr = []
+        pr << fixed_array_size_check if needs_size_check?
+        pr << array_length_assignment if array_length_parameter?
+        pr << out_parameter_preparation
+        pr << ingoing_value_storage
+        pr
+      end
+
+      def pre_conversion_out
+        [out_parameter_preparation]
+      end
+
+      def pre_conversion_error
+        ["#{call_argument_name} = FFI::MemoryPointer.new(:pointer).write_pointer nil"]
+      end
+
       def ingoing_value_storage
         PointerValueConvertor.new(type_spec).
           value_to_pointer(call_argument_name, ingoing_convertor.conversion)
@@ -85,6 +101,7 @@ module GirFFI
 
       def output_value
         return "#{call_argument_name}.get_value" if caller_allocated_object? && gvalue?
+
         base = pointer_to_value_method_call call_argument_name, type_spec
         if needs_out_conversion?
           outgoing_convertor(base).conversion
@@ -193,9 +210,9 @@ module GirFFI
           NullConvertor.new('0')
         elsif destroy_notifier?
           NullConvertor.new(DESTROY_NOTIFIER)
-        elsif closure?
-          ClosureToPointerConvertor.new(pre_convertor_argument, @is_closure)
-        elsif type_info.needs_ruby_to_c_conversion_for_functions?
+        elsif user_data?
+          ClosureToPointerConvertor.new(callback_argument_name)
+        elsif needs_ruby_to_c_conversion?
           RubyToCConvertor.new(type_info, pre_convertor_argument,
                                ownership_transfer: ownership_transfer)
         else
@@ -210,6 +227,14 @@ module GirFFI
           name
         end
       end
+
+      def needs_ruby_to_c_conversion?
+        type_info.needs_ruby_to_c_conversion_for_functions?
+      end
+
+      def callback_argument_name
+        @related_callback_builder.call_argument_name
+      end
     end
   end
 end
