@@ -67,22 +67,35 @@ module GirFFI
       end
 
       def set_up_argument_relations
+        set_up_user_data_relations
+        set_up_destroy_notifier_relations
+        set_up_length_argument_relations
+      end
+
+      def set_up_user_data_relations
         @base_argument_builders.each do |bldr|
           if (idx = bldr.closure_idx) >= 0
-            @base_argument_builders[idx].closure = bldr
+            @base_argument_builders[idx].mark_as_user_data bldr
           end
+        end
+      end
+
+      def set_up_destroy_notifier_relations
+        @base_argument_builders.each do |bldr|
           if (idx = bldr.destroy_idx) >= 0
             @base_argument_builders[idx].mark_as_destroy_notifier bldr
           end
         end
-        all_builders.each do |bldr|
-          if (idx = bldr.array_length_idx) >= 0
-            other = @base_argument_builders[idx]
-            next unless other
+      end
 
-            bldr.length_arg = other
-            other.array_arg = bldr
-          end
+      def set_up_length_argument_relations
+        all_builders.each do |bldr|
+          idx = bldr.array_length_idx
+          next if idx < 0
+
+          other = @base_argument_builders[idx]
+          bldr.length_arg = other
+          other.array_arg = bldr
         end
       end
 
