@@ -26,6 +26,7 @@ module GirFFI
         setup_ffi_type
         klass.extend superclass
         setup_constants
+        setup_value_constants
         stub_methods
         setup_inspect
       end
@@ -40,6 +41,14 @@ module GirFFI
         end
       end
 
+      def setup_value_constants
+        info.values.each do |vinfo|
+          optionally_define_constant klass, vinfo.constant_name do
+            vinfo.value
+          end
+        end
+      end
+
       def setup_inspect
         klass.instance_eval <<-RUBY, __FILE__, __LINE__ + 1
           def self.inspect
