@@ -26,7 +26,7 @@ module GirFFI
 
         def pre_conversion
           [
-            "#{field_ptr} = @struct.to_ptr + #{field_offset}",
+            "#{field_ptr} = @struct.to_ptr",
             "#{bare_value} = #{pointer_to_value_conversion}"
           ]
         end
@@ -58,7 +58,7 @@ module GirFFI
         private
 
         def pointer_to_value_conversion
-          PointerValueConvertor.new(field_type_tag).pointer_to_value(field_ptr)
+          PointerValueConvertor.new(field_type_tag).pointer_to_value(field_ptr, field_offset)
         end
 
         def field_offset
@@ -78,7 +78,7 @@ module GirFFI
         end
 
         def field_type_tag
-          @field_type_tag ||= @field_info.field_type.tag_or_class
+          @field_type_tag ||= field_type.tag_or_class
         end
 
         def field_type
@@ -97,7 +97,7 @@ module GirFFI
       end
 
       # Class to represent argument info for the argument of a getter method.
-      # Implements the necessary parts of IArgumentInfo's interface.
+      # Implements the necessary parts of IArgInfo's interface.
       class GetterArgumentInfo
         attr_reader :name, :argument_type
 
@@ -216,7 +216,7 @@ module GirFFI
         end
 
         def field_type_tag
-          @field_type_tag ||= @info.field_type.tag_or_class.inspect
+          @field_type_tag ||= field_type.tag_or_class.inspect
         end
 
         def field_type
@@ -243,7 +243,8 @@ module GirFFI
       def setup_getter
         return if container_defines_getter_method?
         return if hidden_struct_type?
-        container_class.class_eval getter_def
+
+        container_class.class_eval getter_def, __FILE__, __LINE__
       end
 
       def container_defines_getter_method?
@@ -253,7 +254,8 @@ module GirFFI
       def setup_setter
         return unless info.writable?
         return if hidden_struct_type?
-        container_class.class_eval setter_def
+
+        container_class.class_eval setter_def, __FILE__, __LINE__
       end
 
       def getter_def
@@ -269,7 +271,7 @@ module GirFFI
 
         <<-CODE.reset_indentation
         def #{info.name}= #{builder.method_argument_name}
-          #{field_ptr} = @struct.to_ptr + #{info.offset}
+          #{field_ptr} = @struct.to_ptr
           #{builder.pre_conversion.join("\n          ")}
           #{value_storage(field_ptr, builder)}
         end
@@ -280,7 +282,7 @@ module GirFFI
 
       def value_storage(typed_ptr, builder)
         PointerValueConvertor.new(field_type_tag).
-          value_to_pointer(typed_ptr, builder.call_argument_name)
+          value_to_pointer(typed_ptr, builder.call_argument_name, info.offset)
       end
 
       def field_type_tag
