@@ -28,7 +28,7 @@ module GirFFI
         return false unless go
 
         Builder.attach_ffi_function lib, go
-        modul.class_eval FunctionBuilder.new(go).method_definition
+        modul.class_eval FunctionBuilder.new(go).method_definition, __FILE__, __LINE__
 
         true
       end
@@ -90,9 +90,7 @@ module GirFFI
         lib.extend FFI::Library
         lib.extend FFI::BitMasks
         lib.ffi_lib_flags :global, :lazy
-        if shared_library_specification
-          lib.ffi_lib(*shared_library_specification.split(/,/))
-        end
+        lib.ffi_lib(*shared_library_specification.split(/,/)) if shared_library_specification
       end
 
       def shared_library_specification
@@ -110,6 +108,7 @@ module GirFFI
       def function_introspection_data(function)
         info = gir.find_by_name @namespace, function.to_s
         return unless info
+
         info.info_type == :function ? info : nil
       end
 
