@@ -39,15 +39,6 @@ module GirFFI
         @ancestor_infos ||= [info] + info.interfaces + parent_ancestor_infos
       end
 
-      def eligible_fields
-        info.fields.reject do |finfo|
-          fname = finfo.name
-          fname == 'parent_instance' ||
-            info.find_instance_method("get_#{fname}") ||
-            info.find_property(fname)
-        end
-      end
-
       def eligible_properties
         info.properties.reject do |pinfo|
           info.find_instance_method("get_#{pinfo.name}")
@@ -67,11 +58,10 @@ module GirFFI
         setup_layout
         setup_constants
         stub_methods
-        setup_field_accessors
         setup_property_accessors
         setup_vfunc_invokers
         setup_interfaces
-        provide_initializer
+        setup_initializer
       end
 
       # FIXME: Private method only used in subclass
@@ -99,12 +89,6 @@ module GirFFI
         @parent_ancestor_infos ||= parent_builder.ancestor_infos
       end
 
-      def setup_field_accessors
-        eligible_fields.each do |finfo|
-          FieldBuilder.new(finfo, klass).build
-        end
-      end
-
       def setup_property_accessors
         eligible_properties.each do |prop|
           PropertyBuilder.new(prop).build
@@ -121,6 +105,7 @@ module GirFFI
 
       def define_vfunc_invoker(vfunc_name, invoker_name)
         return if vfunc_name == invoker_name
+
         klass.class_eval <<-DEF, __FILE__, __LINE__ + 1
           def #{vfunc_name} *args, &block
             #{invoker_name}(*args, &block)
@@ -128,24 +113,32 @@ module GirFFI
         DEF
       end
 
-      def provide_initializer
+      def setup_initializer
         return if info.find_method 'new'
 
         if info.abstract?
-          klass.class_eval <<-RUBY, __FILE__, __LINE__ + 1
-            def initialize(*)
-              raise NoMethodError
-            end
-          RUBY
+          define_abstract_initializer
         else
-          klass.class_eval <<-RUBY, __FILE__, __LINE__ + 1
-            def initialize(properties = {})
-              base_initialize(properties)
-            end
-          RUBY
+          define_default_initializer
         end
       end
 
+      def define_abstract_initializer
+        klass.class_eval <<-RUBY, __FILE__, __LINE__ + 1
+          def initialize(*)
+            raise NoMethodError
+          end
+        RUBY
+      end
+
+      def define_default_initializer
+        klass.class_eval <<-RUBY, __FILE__, __LINE__ + 1
+          def initialize(properties = {})
+            base_initialize(properties)
+          end
+        RUBY
+      end
+
       def setup_interfaces
         interfaces.each do |iface|
           klass.send :include, iface
