@@ -16,7 +16,7 @@ module GirFFI
         register_type
         setup_constants
         setup_property_accessors
-        setup_constructor
+        setup_initializer
         TypeBuilder::CACHE[@gtype] = klass
       end
 
@@ -49,7 +49,7 @@ module GirFFI
       end
 
       def included_interfaces
-        klass.included_modules - Object.included_modules
+        klass.included_interfaces
       end
 
       def klass
@@ -86,11 +86,13 @@ module GirFFI
       end
 
       def instance_size
-        size = parent_gtype.instance_size
-        alignment = struct_class.alignment
-        properties.each do |prop|
-          type_size = FFI.type_size(prop.ffi_type)
-          size += [type_size, alignment].max
+        if property_fields.any?
+          last_property = property_fields.last
+          size = last_property.offset
+          type_size = FFI.type_size(last_property.ffi_type)
+          size += [type_size, field_alignment].max
+        else
+          size = parent_gtype.instance_size
         end
         size
       end
@@ -105,7 +107,7 @@ module GirFFI
         object_class.get_property = property_getter
         object_class.set_property = property_setter
 
-        properties.each_with_index do |property, index|
+        property_fields.each_with_index do |property, index|
           object_class.install_property index + 1, property.param_spec
         end
       end
@@ -127,7 +129,7 @@ module GirFFI
           superclass.gir_ffi_builder.object_class_struct::Struct.new(object_class_ptr)
 
         info.vfunc_implementations.each do |impl|
-          setup_vfunc super_class_struct, impl
+          setup_vfunc parent_info, super_class_struct, impl
         end
       end
 
@@ -138,26 +140,16 @@ module GirFFI
         interface_info = interface_builder.info
 
         info.vfunc_implementations.each do |impl|
-          setup_interface_vfunc interface_info, interface_struct, impl
+          setup_vfunc interface_info, interface_struct, impl
         end
       end
 
-      def setup_vfunc(super_class_struct, impl)
+      def setup_vfunc(ancestor_info, ancestor_struct, impl)
         vfunc_name = impl.name
-        vfunc_info = parent_info.find_vfunc vfunc_name.to_s
+        vfunc_info = ancestor_info.find_vfunc vfunc_name.to_s
+        return unless vfunc_info
 
-        if vfunc_info
-          install_vfunc super_class_struct, vfunc_name, vfunc_info, impl.implementation
-        end
-      end
-
-      def setup_interface_vfunc(interface_info, interface_struct, impl)
-        vfunc_name = impl.name
-        vfunc_info = interface_info.find_vfunc vfunc_name.to_s
-
-        if vfunc_info
-          install_vfunc interface_struct, vfunc_name, vfunc_info, impl.implementation
-        end
+        install_vfunc ancestor_struct, vfunc_name, vfunc_info, impl.implementation
       end
 
       def install_vfunc(container_struct, vfunc_name, vfunc_info, implementation)
@@ -166,111 +158,45 @@ module GirFFI
       end
 
       def properties
-        info.properties
+        @properties ||= info.properties
       end
 
       def layout_specification
         parent_spec = [:parent, superclass::Struct]
-        offset = parent_gtype.instance_size
 
-        alignment = superclass::Struct.alignment
-        fields_spec = properties.flat_map do |param_info|
-          field_name = param_info.accessor_name.to_sym
-          ffi_type = param_info.ffi_type
-          type_size = FFI.type_size(ffi_type)
-          spec = [field_name, ffi_type, offset]
-          offset += [type_size, alignment].max
-          spec
+        fields_spec = property_fields.flat_map do |property_info|
+          [property_info.field_symbol, property_info.ffi_type, property_info.offset]
         end
+
         parent_spec + fields_spec
       end
 
-      # TODO: Move this to its own file.
-      # TODO: See if this or FieldTypeInfo can be merged with with
-      # UserDefinedPropertyInfo.
-      class UserDefinedPropertyFieldInfo
-        # Field info for user-defined property
-        class FieldTypeInfo
-          include InfoExt::ITypeInfo
-
-          def initialize(property_info)
-            @property_info = property_info
-          end
-
-          def tag
-            @property_info.type_tag
-          end
-
-          def pointer?
-            @property_info.pointer_type?
-          end
-
-          def interface_type
-            @property_info.interface_type_tag if tag == :interface
-          end
-
-          def hidden_struct_type?
-            false
-          end
-
-          def interface_class
-            Builder.build_by_gtype @property_info.value_type if tag == :interface
-          end
-
-          def interface_class_name
-            interface_class.name if tag == :interface
-          end
-        end
-
-        def initialize(property_info, container, offset)
-          @property_info = property_info
-          @container = container
-          @offset = offset
-        end
-
-        attr_reader :container, :offset
-
-        def name
-          @property_info.accessor_name
-        end
-
-        def field_type
-          @field_type ||= FieldTypeInfo.new @property_info
-        end
-
-        def related_array_length_field
-          nil
-        end
-
-        def writable?
-          @property_info.writable?
-        end
+      def field_alignment
+        @field_alignment ||= superclass::Struct.alignment
       end
 
       def setup_property_accessors
-        offset = parent_gtype.instance_size
-        alignment = struct_class.alignment
-        properties.each do |param_info|
-          field_info = UserDefinedPropertyFieldInfo.new(param_info, info, offset)
-          type_size = FFI.type_size(param_info.ffi_type)
-          offset += [type_size, alignment].max
+        property_fields.each do |field_info|
           FieldBuilder.new(field_info, klass).build
         end
       end
 
+      def property_fields
+        @property_fields ||=
+          begin
+            offset = parent_gtype.instance_size
+            properties.map do |param_spec|
+              field_info = UserDefinedPropertyInfo.new(param_spec, info, offset)
+              type_size = FFI.type_size(field_info.ffi_type)
+              offset += [type_size, field_alignment].max
+              field_info
+            end
+          end
+      end
+
       def method_introspection_data(_method)
         nil
       end
-
-      def setup_constructor
-        code = <<-CODE
-        def initialize
-          ptr = GObject::Lib.g_object_newv #{@gtype}, 0, nil
-          store_pointer(ptr)
-        end
-        CODE
-        klass.class_eval code
-      end
     end
   end
 end
