@@ -21,7 +21,9 @@ module GirFFI
 
       def setup_layout
         spec = layout_specification
-        struct_class.class_eval { layout(*spec) }
+        struct_class.class_eval do
+          layout(*spec)
+        end
       end
 
       def dummy_layout_specification
@@ -41,7 +43,7 @@ module GirFFI
       end
 
       def struct_class
-        @structklass ||= get_or_define_class klass, :Struct, layout_superclass
+        @struct_class ||= get_or_define_class klass, :Struct, layout_superclass
       end
     end
   end
