@@ -17,6 +17,7 @@ module GirFFI
     # TODO: Return instance of this class
     def self.from_native(value, _context)
       return nil if !value || value.null?
+
       FFI::Function.new(gir_ffi_builder.return_ffi_type,
                         gir_ffi_builder.argument_ffi_types, value)
     end
@@ -80,8 +81,8 @@ module GirFFI
       to_native.to_ptr
     end
 
-    def self.copy_value_to_pointer(value, pointer)
-      pointer.put_pointer 0, to_native(value, nil)
+    def self.copy_value_to_pointer(value, pointer, offset = 0)
+      pointer.put_pointer offset, to_native(value, nil)
     end
 
     def self.get_value_from_pointer(pointer, offset)
