@@ -3,6 +3,8 @@
 require 'forwardable'
 require 'gir_ffi/registered_type_base'
 require 'gir_ffi/builders/null_class_builder'
+require 'gir_ffi/method_setup'
+require 'gir_ffi/instance_method_setup'
 
 module GirFFI
   # Base class for all generated classes and structs. Contains code for dealing
@@ -10,6 +12,8 @@ module GirFFI
   class ClassBase
     extend RegisteredTypeBase
     extend Forwardable
+    extend MethodSetup
+    extend InstanceMethodSetup
 
     GIR_FFI_BUILDER = Builders::NullClassBuilder.new
 
@@ -52,12 +56,8 @@ module GirFFI
       self::Struct
     end
 
-    def self.setup_method(name)
-      gir_ffi_builder.setup_method name
-    end
-
-    def self.setup_instance_method(name)
-      gir_ffi_builder.setup_instance_method name
+    def self.to_callback_ffi_type
+      :pointer
     end
 
     # Wrap the passed pointer in an instance of the current class, or a
@@ -70,6 +70,7 @@ module GirFFI
     # do any casting to subtypes or additional processing.
     def self.direct_wrap(ptr)
       return nil if !ptr || ptr.null?
+
       obj = allocate
       obj.__send__ :assign_pointer, ptr
       obj
