@@ -1,27 +1,29 @@
 # frozen_string_literal: true
 
 require 'gir_ffi/registered_type_base'
+require 'gir_ffi/method_setup'
 
 module GirFFI
   # Base module for enums and flags.
   module EnumLikeBase
     include FFI::DataConverter
     include RegisteredTypeBase
+    include MethodSetup
 
     def wrap(arg)
-      self[arg]
+      from_native arg, nil
     end
 
-    def from(arg)
-      self[arg]
+    def to_int(arg)
+      to_native arg, nil
     end
 
     def size
       native_type.size
     end
 
-    def copy_value_to_pointer(value, pointer)
-      pointer.put_int32 0, to_native(value, nil)
+    def copy_value_to_pointer(value, pointer, offset = 0)
+      pointer.put_int32 offset, to_native(value, nil)
     end
 
     def get_value_from_pointer(pointer, offset)
@@ -40,8 +42,8 @@ module GirFFI
       self
     end
 
-    def setup_method(name)
-      gir_ffi_builder.setup_method name
+    def to_callback_ffi_type
+      :int32
     end
   end
 end
