@@ -8,13 +8,10 @@ module GirFFI
         self
       end
 
-      def zero?
-        null?
-      end
-
       # FIXME: Should probably not be here.
       def to_object
         return nil if null?
+
         gtype = GObject.type_from_instance_pointer self
         Builder.build_by_gtype(gtype).direct_wrap self
       end
