@@ -7,24 +7,16 @@ module GirFFI
   module InPointer
     def self.from_array(type, ary)
       return unless ary
+
       case type
-      when :utf8, :filename
-        from_utf8_array ary
-      when :gboolean
-        from_boolean_array ary
       when Symbol
-        from_basic_type_array type, ary
-      when Class
-        if type == GObject::Value
-          from_gvalue_array type, ary
-        else
-          from_struct_array type, ary
-        end
+        from_simple_type_array type, ary
       when Module
-        from_enum_array type, ary
+        from_module_type_array type, ary
       when Array
         main_type, sub_type = *type
         raise "Unexpected main type #{main_type}" if main_type != :pointer
+
         from_pointer_array sub_type, ary
       else
         raise NotImplementedError, type
@@ -33,6 +25,7 @@ module GirFFI
 
     def self.from(type, val)
       return unless val
+
       case type
       when :utf8, :filename
         from_utf8 val
@@ -47,9 +40,40 @@ module GirFFI
       end
     end
 
+    def self.from_utf8(str)
+      return unless str
+
+      ptr = FFI::MemoryPointer.from_string(str)
+      ptr.autorelease = false
+      ptr
+    end
+
     class << self
       private
 
+      def from_simple_type_array(type, ary)
+        case type
+        when :utf8, :filename
+          from_utf8_array ary
+        when :gboolean
+          from_boolean_array ary
+        else
+          from_basic_type_array type, ary
+        end
+      end
+
+      def from_module_type_array(type, ary)
+        if type == GObject::Value
+          from_gvalue_array type, ary
+        elsif type < GirFFI::ClassBase
+          from_struct_array type, ary
+        elsif type.singleton_class.include? GirFFI::EnumBase
+          from_enum_array type, ary
+        else
+          raise NotImplementedError, type
+        end
+      end
+
       def from_utf8_array(ary)
         from_basic_type_array :pointer, ary.map { |str| from_utf8 str }
       end
@@ -90,17 +114,6 @@ module GirFFI
         from_basic_type_array :int32, ary.map { |sym| type.to_native sym, nil }
       end
 
-      public
-
-      def from_utf8(str)
-        return unless str
-        ptr = FFI::MemoryPointer.from_string(str)
-        ptr.autorelease = false
-        ptr
-      end
-
-      private
-
       def from_basic_type_array(type, ary)
         ffi_type = TypeMap.type_specification_to_ffi_type type
         type_size = FFI.type_size(ffi_type)
