@@ -1,26 +1,23 @@
 # frozen_string_literal: true
 
 require 'gir_ffi/registered_type_base'
+require 'gir_ffi/method_setup'
+require 'gir_ffi/instance_method_setup'
 
 module GirFFI
   # Base module for modules representing GLib interfaces.
   module InterfaceBase
     include RegisteredTypeBase
+    include MethodSetup
+    include InstanceMethodSetup
 
     def setup_and_call(method, arguments, &block)
       method_name = setup_method method.to_s
       raise NoMethodError, "undefined method `#{method}' for #{self}" unless method_name
+
       send method_name, *arguments, &block
     end
 
-    def setup_instance_method(name)
-      gir_ffi_builder.setup_instance_method name
-    end
-
-    def setup_method(name)
-      gir_ffi_builder.setup_method name
-    end
-
     def wrap(ptr)
       ptr.to_object
     end
@@ -28,5 +25,9 @@ module GirFFI
     def to_ffi_type
       :pointer
     end
+
+    def to_callback_ffi_type
+      :pointer
+    end
   end
 end
