@@ -1,11 +1,16 @@
 # frozen_string_literal: true
 
+require 'gir_ffi/method_setup'
+
 module GirFFI
   # Base module for modules representing GLib namespaces.
   module ModuleBase
+    include MethodSetup
+
     def method_missing(method, *arguments, &block)
       result = setup_method method.to_s
       return super unless result
+
       send method, *arguments, &block
     end
 
@@ -24,9 +29,5 @@ module GirFFI
     def gir_ffi_builder
       self::GIR_FFI_BUILDER
     end
-
-    def setup_method(name)
-      gir_ffi_builder.setup_method name
-    end
   end
 end
