@@ -19,8 +19,8 @@ module GirFFI
       self
     end
 
-    def self.to_native(it, _)
-      it.to_ptr
+    def self.to_native(obj, _context)
+      obj.to_ptr
     end
 
     def self.get_value_from_pointer(pointer, offset = 0)
@@ -72,5 +72,15 @@ module GirFFI
           gir_ffi_builder.object_class_struct.wrap ptr
         end
     end
+
+    def self.included_interfaces
+      included_modules.select { |it| it.singleton_class.include? InterfaceBase }
+    end
+
+    def self.registered_ancestors
+      ancestors.select do |it|
+        it < GirFFI::ObjectBase || it.singleton_class.include?(InterfaceBase)
+      end
+    end
   end
 end
