@@ -1,19 +1,18 @@
 # frozen_string_literal: true
 
-require 'rubygems' if RUBY_PLATFORM == 'java'
+require 'simplecov'
+SimpleCov.start do
+  track_files 'lib/**/*.rb'
+  add_filter '/test/'
+end
 
-begin
-  require 'simplecov'
-  SimpleCov.start do
-    track_files 'lib/**/*.rb'
-    add_filter '/test/'
-  end
-
-  if ENV['CI']
+if ENV['CI']
+  begin
     require 'coveralls'
     Coveralls.wear!
+  rescue LoadError
+    nil
   end
-rescue LoadError
 end
 
 require 'minitest/autorun'
