@@ -87,7 +87,7 @@ describe GirFFI::Builder do
 
       found_klass = GirFFI::Builder.build_by_gtype gtype
       found_klass.name.must_be_nil
-      found_klass.ancestors.must_include GirFFI::BoxedBase
+      found_klass.superclass.must_equal GirFFI::BoxedBase
     end
   end
 
@@ -136,6 +136,14 @@ describe GirFFI::Builder do
       GirFFI::Builder.attach_ffi_function(lib, info)
     end
 
+    it 'calls attach_function with the correct types for Regress.test_enum_param' do
+      info = get_introspection_data 'Regress', 'test_enum_param'
+      expect(lib).to receive(:attach_function).
+        with('regress_test_enum_param', [Regress::TestEnum], :pointer).
+        and_return true
+      GirFFI::Builder.attach_ffi_function(lib, info)
+    end
+
     it 'does not attach the function if it is already defined' do
       info = get_introspection_data 'Regress', 'test_array_gint32_in'
       allow(lib).to receive(:method_defined?).and_return true
@@ -158,7 +166,7 @@ describe GirFFI::Builder do
     end
 
     it 'defines ffi callback types :Callback and :ClosureNotify' do
-      Regress.setup_method 'test_callback_destroy_notify'
+      Regress.setup_method! 'test_callback_destroy_notify'
       tcud = Regress::Lib.find_type :TestCallbackUserData
       dn = GLib::Lib.find_type :DestroyNotify
 
@@ -275,12 +283,10 @@ describe GirFFI::Builder do
     end
 
     it 'sets up the inheritance chain' do
-      ancestors = Regress::TestSubObj.ancestors
-      assert_equal [
-        Regress::TestSubObj,
-        Regress::TestObj,
-        GObject::Object
-      ], ancestors[0..2]
+      Regress::TestSubObj.registered_ancestors.
+        must_equal [Regress::TestSubObj,
+                    Regress::TestObj,
+                    GObject::Object]
     end
 
     it 'creates a Regress::TestSubObj#to_ptr method' do
