@@ -12,7 +12,7 @@ describe GirFFI::Builders::SignalClosureBuilder do
 
     it 'builds a descendant of RubyClosure' do
       klass = builder.build_class
-      klass.ancestors.must_include GObject::RubyClosure
+      klass.superclass.must_equal GObject::RubyClosure
     end
   end
 
