@@ -17,7 +17,9 @@ module Minitest
     def report
       slowest = @results.sort_by(&:time).reverse.first(10)
       slowest.each do |result|
-        puts format('%10.4f %s', result.time, result.location)
+        puts format('%<time>10.4f %<location>s',
+                    time: result.time,
+                    location: result.location)
       end
     end
   end
